@@ -1,6 +1,6 @@
 /*
  * music player command (mpc)
- * Copyright (C) 2003-2017 The Music Player Daemon Project
+ * Copyright 2003-2018 The Music Player Daemon Project
  * http://www.musicpd.org
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 #ifndef OPTIONS_H
 #define OPTIONS_H
 
-#include "stdbool.h"
+#include <stdbool.h>
 
 #define V_QUIET 0
 #define V_DEFAULT 1
@@ -29,22 +29,29 @@
 #define F_DEFAULT \
     "[%name%: &[[%artist%|%performer%] - ]%title%]|%name%|[[%artist%|%performer%] - ]%title%|%file%"
 
-typedef struct {
+struct Range {
+	unsigned start, end;
+};
+
+struct Options {
 	const char *host;
 	const char *port_str;
 	int port;
 	const char *password;
 	const char *format;
+
+	struct Range range;
+
 	int verbosity; // 0 for quiet, 1 for default, 2 for verbose
 	bool wait;
 
 	bool custom_format;
-} options_t;
+};
 
 
 void print_option_help(void);
 void parse_options(int * argc_p, char ** argv);
 
-extern options_t options;
+extern struct Options options;
 
 #endif /* OPTIONS_H */
